/* $Id: test.cc,v 1.5 2003/06/29 03:09:34 tetron Exp $

    Copyright (C) 2002 Peter Amstutz <tetron@interreality.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA

*/

#include <stdexcept>
#include <iostream>
#include "servicedirectory.hh"

using namespace LSD;
using namespace std;

class testcb : public virtual ServiceAdvertismentListener {
public:
    virtual void notifyNewService(int id, const Service& s)
    {
        cout << "* found service (for query id " << id << ")!\n";
        cout << "* title: " << s.title << "\n";
        cout << "* description: " << s.description << "\n";
        cout << "* url: " << s.url << "\n\n";
    }
};

int main(int argc, char** argv)
{
    try {
        ServiceDirectory sd;
        sd.listenTCP();
        try {
            cerr << "Relaying to tcp localhost:4444...\n";
            sd.addRelay("localhost", 4444);
        } catch(...) {
            cerr << "Cannot relay to localhost:4444 (connection failed)\n";
        }
        cerr << "Advertising a new service...\n";
        set<string> types;
        types.insert("hello:hello");
        sd.addService(new Service(types, "some title", "la la de da", "httvosnmldaftirc://shwing"));
        cerr << "Making query (url matches /htt.*/)...\n";
        int q = sd.query("", "", "", "htt.*", new testcb());
        cerr << "query id is " << q << endl;
        while(true)
            sd.handleIncoming();
    } catch(runtime_error& e) {
        cerr << "Error: " << e.what() << endl;
    }
}
